@@ -1,7 +1,6 @@
-/* SPDX-FileCopyrightText: 2014 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
+// SPDX-FileCopyrightText: 2014-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef CATEGORYMODEL_H
 #define CATEGORYMODEL_H
@@ -32,7 +31,7 @@ public:
     void setCategories(const QList<Category> &);
     bool hasData() const;
 
-signals:
+Q_SIGNALS:
     void hasDataChanged();
 
 private:
