@@ -1,7 +1,6 @@
-/* SPDX-FileCopyrightText: 2012 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-*/
+// SPDX-FileCopyrightText: 2012-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #ifndef JOBINFO_H
 #define JOBINFO_H
@@ -35,11 +34,11 @@ public:
     QString elapsed() const;
     int jobIndex() const;
 
-protected slots:
+protected Q_SLOTS:
     void start();
     void stop();
 
-signals:
+Q_SIGNALS:
     void changed() const;
 
 private:
