@@ -1,7 +1,6 @@
-/* SPDX-FileCopyrightText: 2012 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-*/
+// SPDX-FileCopyrightText: 2012-2022 Jesper K. Pedersen <blackie@kde.org>
+//
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #ifndef BACKGROUNDTASKS_JOBMODEL_H
 #define BACKGROUNDTASKS_JOBMODEL_H
@@ -26,10 +25,10 @@ public:
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
 
-public slots:
+public Q_SLOTS:
     void reset();
 
-private slots:
+private Q_SLOTS:
     void jobEnded(JobInterface *job);
     void jobStarted(JobInterface *job);
 
