@@ -1,13 +1,14 @@
-/* SPDX-FileCopyrightText: 2003-2019 The KPhotoAlbum Development Team
-
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
+// SPDX-FileCopyrightText: 2009 Jan Kundrát <jkt@flaska.net>
+// SPDX-FileCopyrightText: 2009-2013 Jesper K. Pedersen <jesper.pedersen@kdab.com>
+// SPDX-FileCopyrightText: 2013-2023 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef ABSTRACTCATEGORYMODEL_H
 #define ABSTRACTCATEGORYMODEL_H
 #include <DB/Category.h>
 #include <DB/CategoryPtr.h>
-#include <DB/ImageSearchInfo.h>
+#include <DB/search/ImageSearchInfo.h>
 
 #include <QAbstractItemModel>
 
