@@ -2,13 +2,13 @@
 // SPDX-FileCopyrightText: 2006-2014 Jesper K. Pedersen <jesper.pedersen@kdab.com>
 // SPDX-FileCopyrightText: 2007 Dirk Mueller <mueller@kde.org>
 // SPDX-FileCopyrightText: 2007 Laurent Montel <montel@kde.org>
-// SPDX-FileCopyrightText: 2008-2011 Jan Kundrát <jkt@flaska.net>
 // SPDX-FileCopyrightText: 2008-2009 Henner Zeller <h.zeller@acm.org>
-// SPDX-FileCopyrightText: 2012 Yuri Chornoivan <yurchor@ukr.net>
+// SPDX-FileCopyrightText: 2008-2011 Jan Kundrát <jkt@flaska.net>
 // SPDX-FileCopyrightText: 2012-2013 Miika Turkia <miika.turkia@gmail.com>
-// SPDX-FileCopyrightText: 2018-2020 Robert Krawitz <rlk@alum.mit.edu>
-// SPDX-FileCopyrightText: 2012-2023 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2012-2025 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2012 Yuri Chornoivan <yurchor@ukr.net>
 // SPDX-FileCopyrightText: 2014-2024 Tobias Leupold <tl@stonemx.de>
+// SPDX-FileCopyrightText: 2018-2020 Robert Krawitz <rlk@alum.mit.edu>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -31,8 +31,8 @@
 #include <QFile>
 #include <QFileInfo>
 #include <QMutexLocker>
-#include <QXmlStreamWriter>
 #include <QRegularExpression>
+#include <QXmlStreamWriter>
 
 #include <utility>
 
@@ -65,9 +65,10 @@ constexpr QFileDevice::Permissions FILE_PERMISSIONS { QFile::ReadOwner | QFile::
 void DB::FileWriter::save(const QString &fileName, bool isAutoSave)
 {
     setUseCompressedFileFormat(Settings::SettingsData::instance()->useCompressedIndexXML());
+    qCDebug(DBLog) << "Saving" << (useCompressedFileFormat() ? "compressed" : "uncompressed") << "file format.";
 
     if (!isAutoSave)
-        NumberedBackup(m_db->uiDelegate()).makeNumberedBackup();
+        NumberedBackup(m_db->uiDelegate(), fileName).makeNumberedBackup();
 
     // prepare XML document for saving:
     m_db->m_categoryCollection.initIdMap();
@@ -105,7 +106,7 @@ void DB::FileWriter::save(const QString &fileName, bool isAutoSave)
     writer.writeEndDocument();
     qCDebug(TimingLog) << "DB::FileWriter::save(): Saving took" << timer.elapsed() << "ms";
 
-    // State: index.xml has previous DB version, index.xml.tmp has the current version.
+    // State: XML file has previous DB version, temp file has the current version.
 
     // original file can be safely deleted
     if ((!QFile::remove(fileName)) && QFile::exists(fileName)) {
@@ -116,17 +117,17 @@ void DB::FileWriter::save(const QString &fileName, bool isAutoSave)
             i18n("Error while saving..."));
         return;
     }
-    // State: index.xml doesn't exist, index.xml.tmp has the current version.
+    // State: XML file doesn't exist, temp file has the current version.
     if (!out.rename(fileName)) {
         m_db->uiDelegate().error(
-            DB::LogMessage { DBLog(), QStringLiteral("Renaming index.xml to '%1' failed.").arg(out.fileName()) }, i18n("<p>Failed to move temporary XML file to permanent location.</p>"
-                                                                                                                       "<p>Please try again or rename file %1 to %2 manually!</p>",
-                                                                                                                       out.fileName(), fileName),
+            DB::LogMessage { DBLog(), QStringLiteral("Renaming '%1' to '%2' failed.").arg(out.fileName().arg(fileName)) }, i18n("<p>Failed to move temporary XML file to permanent location.</p>"
+                                                                                                                                "<p>Please try again or rename file %1 to %2 manually!</p>",
+                                                                                                                                out.fileName(), fileName),
             i18n("Error while saving..."));
-        // State: index.xml.tmp has the current version.
+        // State: temp file has the current version.
         return;
     }
-    // State: index.xml has the current version.
+    // State: XML file has the current version.
 }
 
 void DB::FileWriter::saveCategories(QXmlStreamWriter &writer)
@@ -156,7 +157,7 @@ void DB::FileWriter::saveCategories(QXmlStreamWriter &writer)
 
         // As bug 423334 shows, it is easy to forget to add a group to the respective category
         // when it's created. We can not enforce correct creation of member groups in our API,
-        // but we can prevent incorrect data from entering index.xml.
+        // but we can prevent incorrect data from entering the XML file.
         const auto categoryItems = Utilities::mergeListsUniqly(category->items(), m_db->memberMap().groups(name));
         for (const QString &tagName : categoryItems) {
             ElementWriter dummy(writer, QStringLiteral("value"));
@@ -502,28 +503,30 @@ QString DB::FileWriter::escape(const QString &str)
     if (s_cache.contains(str))
         return s_cache[str];
 
-    QString tmp(str);
-    // Regex to match characters that are not allowed to start XML attribute names
-    static const QRegularExpression rx(QStringLiteral("([^a-zA-Z0-9:_])"));
-    int pos = 0;
+    QString escaped;
 
     // Encoding special characters if compressed XML is selected
-    // FIXME: KF6 port: Please review if this still does the same as the QRegExp stuff did
     if (useCompressedFileFormat()) {
-        auto match = rx.match(tmp);
-        while (match.hasMatch()) {
-            QString before = match.captured(1);
-            QString after = QString::asprintf("_.%0X", match.captured(1).data()->toLatin1());
-            tmp.replace(pos, before.length(), after);
-            pos += after.length();
-            match = rx.match(tmp, pos);
+        static const QRegularExpression rx(QStringLiteral("([^a-zA-Z0-9:_])"));
+        QString tmp(str);
+        while (true) {
+            const auto match = rx.match(tmp);
+            if (match.hasMatch()) {
+                escaped += tmp.left(match.capturedStart())
+                    + QString::asprintf("_.%0X", match.captured().data()->toLatin1());
+                tmp = tmp.mid(match.capturedStart() + match.capturedLength(), -1);
+            } else {
+                escaped += tmp;
+                break;
+            }
         }
     } else {
-        tmp.replace(QStringLiteral(" "), QStringLiteral("_"));
+        escaped = str;
+        escaped.replace(QStringLiteral(" "), QStringLiteral("_"));
     }
 
-    s_cache.insert(str, tmp);
-    return tmp;
+    s_cache.insert(str, escaped);
+    return escaped;
 }
 
 // vi:expandtab:tabstop=4 shiftwidth=4:
